# Procedures specific to nfwmass model.
#
############################################################
#
# Allows generic check that the model is known
#
proc nfwmassKnown {} {
    return 1
}
#
############################################################
#
# Deduce maximum possible shells from total number of parameters
#
proc nfwmassMaxShells {mixpars} {
    return [expr $mixpars - 6]
}
#
############################################################
#
# Model has density parameters
#
proc nfwmassHasDens {} {
    return 0
}
#
############################################################
#
# Form of NFW mass distribution
#
proc nfwMfunc {x} {
    if {$x < 0.001} {
	return [expr $x * $x * (0.5 - $x * ((2.0 / 3.0) - $x * (0.75 \
						     - $x * (0.8 * $x))))]
    }
    return [expr log (1.0 + $x) - $x / (1.0 + $x)]
}
#
############################################################
#
# Mass in model units
#
proc nfwmassMofR {r rbName} {
    tclout compinfo 1
    set mixpars [lindex $xspec_tclout 2]
    set pnuma [expr $mixpars - 1]
    set pnumpot $mixpars
    tclout pinfo $pnuma
    set pa [lindex $xspec_tclout 0]
    tclout pinfo $pnumpot
    set ppot [lindex $xspec_tclout 0]
    if {$pa != nfwa || $ppot != nfwpot} {
	puts stderr "nfwmassMofR: wrong model parameters"
	return
    }
    tclout param $pnuma
    set nfwa [lindex $xspec_tclout 0]
    tclout param $pnumpot
    set nfwpot [lindex $xspec_tclout 0]
    return $nfwpot * $nfwa * [nfwMfunc [expr $r / $nfwa]]
}
